@@ -1,7 +1,8 @@
 'use strict';
 var path = require('path');
 module.exports = {
-  target: 'web',
+  mode: 'development',
+  target: 'node',
   resolve: {
     modules: ['/usr/lib/nodejs', '.'],
   },
